==> litspy-0.0.1-py3-none-any.whl: litspy/anatomy_qualifiers.py <==
# based upon the anatomy qualifiers node of the NCI Thesaurus (NCIT_C13442), obtained 2020-03-27
# these elements are manually selected to include adjectives for "relating to anatomical structures",
# and to exclude adjectives for positions of anatomical structures
# (e.g. include "renal" and "oral", but exclude "distal" and "frontal")


anatomy_qualifiers = {'trachea': ['Endotracheal', 'Paratracheal', 'Tracheobronchial'],
                      'hepatocyte': ['Hepatocellular'],
                      'posterior mediastinum': ['Retrocrural'],
                      'portal vein': ['Portacaval'],
                      'inferior vena cava': ['Portacaval'],
                      'mouth': ['Orofacial', 'Oromucosal', 'Oral'],
                      'face': ['Orofacial', 'Facial'],
                      'neck': ['Cervical'],
                      'cervix': ['Cervical', 'Endocervical'],
                      'thorax': ['Intrathoracal', 'Thoracoabdominal', 'Intrathoracic'],
                      'abdomen': ['Intra-abdominal', 'Abdominal', 'Thoracoabdominal'],
                      'rectum': ['Endorectal', 'Colorectal', 'Rectal', 'Anorectal'],
                      'carotid arteries': ['Intracarotid'],
                      'apex of the root of a tooth': ['Periapical'],
                      'lungs': ['Pulmonary', 'Cardiopulmonary'],
                      'stomach': ['Gastric', 'Gastrointestinal', 'Perigastric'],
                      'liver': ['Hepatic', 'Intrahepatic', 'Hepatojugular'],
                      'vagina': ['Vaginal', 'Labial'],
                      'blood vessel': ['Vascular', 'Cardiovascular', 'Cerebrovascular'],
                      'endometrium': ['Endometrial'],
                      'blood': ['Hematopoietic', 'Hematologic'],
                      'nose': ['Nasal', 'Transnasal'],
                      'prostate': ['Prostatic'],
                      'brain ventricle': ['Intraventricular', 'Ventricular'],
                      'heart ventricle': ['Intraventricular', 'Ventricular'],
                      'lymphocyte': ['Lymphocytic'],
                      'peritoneal cavity': ['Intraperitoneal'],
                      'intestine': ['Gastrointestinal', 'Intestinal'],
                      'heart': ['Cardiopulmonary', 'Pericardial', 'Cardiovascular', 'Cardiothoracic'],
                      'colon': ['Colorectal'],
                      'large bowel': ['Colorectal'],
                      'myelocyte': ['Myelogenous'],
                      'myeloid': ['Myelogenous'],
                      'erythrocyte': ['Erythroid'],
                      'cerebrum': ['Intracerebral'],
                      'vagus nerve': ['Vasovagal'],
                      'spine': ['Spinal'],
                      'saliva': ['Salivary'],
                      'pericardium': ['Pericardial'],
                      'mammae': ['Intramammary'],
                      'urinary bladder': ['Intravesical', 'Urethral'],
                      'urethra': ['Intravesical', 'Urethral'],
                      'skin': ['Cutaneous', 'Transdermal'],
                      'hair': ['Cutaneous', 'Transdermal'],
                      'nail': ['Cutaneous', 'Transdermal'],
                      'uterus': ['Endocervical', 'Intrauterine'],
                      'root of a tooth': ['Periradicular'],
                      'artery': ['Transarterial'],
                      'head': ['Occipital'],
                      'mediastinum': ['Mediastinal'],
                      'peritoneum': ['Peritoneal', 'Mesorectal', 'Transperitoneal'],
                      'nerve': ['Neurologic', 'Neuromuscular'],
                      'nervous system': ['Neurologic', 'Neural'],
                      'lymph': ['Lymphatic'],
                      'bronchus': ['Bronchial'],
                      'pleura': ['Pleural'],
                      'mesentery': ['Mesenteric', 'Mesorectal'],
                      'kidney': ['Renal'],
                      'vein': ['Venous'],
                      'eye': ['Periorbital', 'Ocular'],
                      'hilum': ['Hilar'],
                      'pancreas': ['Pancreatic'],
                      'urine': ['Urinary'],
                      'vertebrae': ['Vertebral'],
                      'semen': ['Seminal'],
                      'chest': ['Pectoral', 'Cardiothoracic'],
                      'parametrium': ['Parametrial'],
                      'myometrium': ['Myometrial'],
                      'myocardium': ['Myocardial'],
                      'lymphatic vessel': ['Lymphovascular'],
                      'lobule': ['Lobular'],
                      'lobe': ['Lobar'],
                      'clavicle': ['Intraclavicular'],
                      'fissure': ['Fissural'],
                      'dermis': ['Dermal'],
                      'neuron': ['Neural'],
                      'neurone': ['Neural'],
                      'genital': ['Genitourinary'],
                      'urinary': ['Genitourinary'],
                      'muscle': ['Musculoskeletal', 'Perimysial', 'Neuromuscular'],
                      'skeleton': ['Musculoskeletal', 'Skeletal'],
                      'esophagus': ['Paraesophageal', 'Esophageal'],
                      'cranium': ['Intracranial', 'Craniospinal', 'Cranial'],
                      'spinal column': ['Craniospinal'],
                      'tooth': ['Dental'],
                      'teeth': ['Dental'],
                      'palm of hand': ['Volar'],
                      'sole of foot': ['Volar'],
                      'falx cerebri': ['Falcine'],
                      'temporal bone': ['Temporooccipital', 'Frontotemporal'],
                      'occipital bone': ['Temporooccipital'],
                      'skull': ['Temporooccipital', 'Frontotemporal'],
                      'frontal bone': ['Frontotemporal'],
                      'anus': ['Anorectal', 'Anal'],
                      'skullcap': ['Calvarial'],
                      'ventricle': ['Transventricular'],
                      'brain': ['Cerebrovascular'],
                      'submucosa': ['Submucosal'],
                      'zygomatic bone': ['Malar'],
                      'cheek': ['Malar'],
                      'lip': ['Labial'],
                      'vulva': ['Labial', 'vulval'],
                      'spinal cord': ['Intramedullary'],
                      'marrow space': ['Intramedullary'],
                      'ear': ['Auricular'],
                      'jugular vein': ['Hepatojugular'],
                      'tail': ['Caudal'],
                      'fallopian tube': ['Tubo-Ovarian'],
                      'ovary': ['Tubo-Ovarian'],
                      'alveoli': ['Alveolar'],
                      'bronchi': ['Tracheobronchial', 'bronchial'],
                      'retina': ['Retinal'],
                      'retroperitoneum': ['Retroperitoneal'],
                      'septum': ['Septate'],
                      'glomerulus': ['Glomerular']}

==> litspy-0.0.4-py3-none-any.whl: litspy/anatomy_qualifiers.py <==
# based upon the anatomy qualifiers node of the NCI Thesaurus (NCIT_C13442), obtained 2020-03-27
# these elements are manually selected to include adjectives for "relating to anatomical structures",
# and to exclude adjectives for positions of anatomical structures
# (e.g. include "renal" and "oral", but exclude "distal" and "frontal")


anatomy_qualifiers = {'trachea': ['Endotracheal', 'Paratracheal', 'Tracheobronchial'],
                      'hepatocyte': ['Hepatocellular'],
                      'posterior mediastinum': ['Retrocrural'],
                      'portal vein': ['Portacaval'],
                      'inferior vena cava': ['Portacaval'],
                      'mouth': ['Orofacial', 'Oromucosal', 'Oral'],
                      'face': ['Orofacial', 'Facial'],
                      'neck': ['Cervical'],
                      'cervix': ['Cervical', 'Endocervical'],
                      'thorax': ['Intrathoracal', 'Thoracoabdominal', 'Intrathoracic'],
                      'abdomen': ['Intra-abdominal', 'Abdominal', 'Thoracoabdominal'],
                      'rectum': ['Endorectal', 'Colorectal', 'Rectal', 'Anorectal'],
                      'carotid arteries': ['Intracarotid'],
                      'apex of the root of a tooth': ['Periapical'],
                      'lungs': ['Pulmonary', 'Cardiopulmonary'],
                      'stomach': ['Gastric', 'Gastrointestinal', 'Perigastric'],
                      'liver': ['Hepatic', 'Intrahepatic', 'Hepatojugular'],
                      'vagina': ['Vaginal', 'Labial'],
                      'blood vessel': ['Vascular', 'Cardiovascular', 'Cerebrovascular'],
                      'endometrium': ['Endometrial'],
                      'blood': ['Hematopoietic', 'Hematologic'],
                      'nose': ['Nasal', 'Transnasal'],
                      'prostate': ['Prostatic'],
                      'brain ventricle': ['Intraventricular', 'Ventricular'],
                      'heart ventricle': ['Intraventricular', 'Ventricular'],
                      'lymphocyte': ['Lymphocytic'],
                      'peritoneal cavity': ['Intraperitoneal'],
                      'intestine': ['Gastrointestinal', 'Intestinal'],
                      'heart': ['Cardiopulmonary', 'Pericardial', 'Cardiovascular', 'Cardiothoracic'],
                      'colon': ['Colorectal'],
                      'large bowel': ['Colorectal'],
                      'myelocyte': ['Myelogenous'],
                      'myeloid': ['Myelogenous'],
                      'erythrocyte': ['Erythroid'],
                      'cerebrum': ['Intracerebral'],
                      'vagus nerve': ['Vasovagal'],
                      'spine': ['Spinal'],
                      'saliva': ['Salivary'],
                      'pericardium': ['Pericardial'],
                      'mammae': ['Intramammary'],
                      'urinary bladder': ['Intravesical', 'Urethral'],
                      'urethra': ['Intravesical', 'Urethral'],
                      'skin': ['Cutaneous', 'Transdermal'],
                      'hair': ['Cutaneous', 'Transdermal'],
                      'nail': ['Cutaneous', 'Transdermal'],
                      'uterus': ['Endocervical', 'Intrauterine'],
                      'root of a tooth': ['Periradicular'],
                      'artery': ['Transarterial'],
                      'head': ['Occipital'],
                      'mediastinum': ['Mediastinal'],
                      'peritoneum': ['Peritoneal', 'Mesorectal', 'Transperitoneal'],
                      'nerve': ['Neurologic', 'Neuromuscular'],
                      'nervous system': ['Neurologic', 'Neural'],
                      'lymph': ['Lymphatic'],
                      'bronchus': ['Bronchial'],
                      'pleura': ['Pleural'],
                      'mesentery': ['Mesenteric', 'Mesorectal'],
                      'kidney': ['Renal'],
                      'vein': ['Venous'],
                      'eye': ['Periorbital', 'Ocular'],
                      'hilum': ['Hilar'],
                      'pancreas': ['Pancreatic'],
                      'urine': ['Urinary'],
                      'vertebrae': ['Vertebral'],
                      'semen': ['Seminal'],
                      'chest': ['Pectoral', 'Cardiothoracic'],
                      'parametrium': ['Parametrial'],
                      'myometrium': ['Myometrial'],
                      'myocardium': ['Myocardial'],
                      'lymphatic vessel': ['Lymphovascular'],
                      'lobule': ['Lobular'],
                      'lobe': ['Lobar'],
                      'clavicle': ['Intraclavicular'],
                      'fissure': ['Fissural'],
                      'dermis': ['Dermal'],
                      'neuron': ['Neural'],
                      'neurone': ['Neural'],
                      'genital': ['Genitourinary'],
                      'urinary': ['Genitourinary'],
                      'muscle': ['Musculoskeletal', 'Perimysial', 'Neuromuscular'],
                      'skeleton': ['Musculoskeletal', 'Skeletal'],
                      'esophagus': ['Paraesophageal', 'Esophageal'],
                      'cranium': ['Intracranial', 'Craniospinal', 'Cranial'],
                      'spinal column': ['Craniospinal'],
                      'tooth': ['Dental'],
                      'teeth': ['Dental'],
                      'palm of hand': ['Volar'],
                      'sole of foot': ['Volar'],
                      'falx cerebri': ['Falcine'],
                      'temporal bone': ['Temporooccipital', 'Frontotemporal'],
                      'occipital bone': ['Temporooccipital'],
                      'skull': ['Temporooccipital', 'Frontotemporal'],
                      'frontal bone': ['Frontotemporal'],
                      'anus': ['Anorectal', 'Anal'],
                      'skullcap': ['Calvarial'],
                      'ventricle': ['Transventricular'],
                      'brain': ['Cerebrovascular'],
                      'submucosa': ['Submucosal'],
                      'zygomatic bone': ['Malar'],
                      'cheek': ['Malar'],
                      'lip': ['Labial'],
                      'vulva': ['Labial', 'vulval'],
                      'spinal cord': ['Intramedullary'],
                      'marrow space': ['Intramedullary'],
                      'ear': ['Auricular'],
                      'jugular vein': ['Hepatojugular'],
                      'tail': ['Caudal'],
                      'fallopian tube': ['Tubo-Ovarian'],
                      'ovary': ['Ovarian', 'Tubo-Ovarian'],
                      'alveoli': ['Alveolar'],
                      'bronchi': ['Tracheobronchial', 'bronchial'],
                      'retina': ['Retinal'],
                      'retroperitoneum': ['Retroperitoneal'],
                      'septum': ['Septate'],
                      'glomerulus': ['Glomerular']}
